@@ -1,4 +1,3 @@
-
 class _MetaSingleton(type):
     _instance = {}
 
@@ -8,13 +7,30 @@ class _MetaSingleton(type):
         return cls._instance[cls]
 
 
-class DBHelper(object):
+class _DBHelperConfig(object):
+    def __init__(self, db_helper, db, **kwargs):
+        self.db_helper = db_helper
+        self.db = db
+        self.configure_args = kwargs
 
-    def __init__(self):
+    @property
+    def metadata(self):
+        return self.db.metadata
+
+
+class DBHelper(metaclass=_MetaSingleton):
+
+    def __init__(self, app=None, db=None, **kwargs):
         self.db = None
+        if app is not None and db is not None:
+            self.init_app(app, db)
 
     def init_app(self, app, db):
-        self.db = db
+        self.db = db or self.db
+        if not hasattr(app, 'extensions'):
+            app.extensions = {}
+        app.extensions['db_helper'] = _DBHelperConfig(
+            self, self.db)
 
     def flush(self):
         return _Flush(db=self.db)
@@ -28,7 +44,7 @@ class _Flush(metaclass=_MetaSingleton):
         self._db = db
 
     def __enter__(self):
-        pass
+        return self._db
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         self._db.session.flush()
@@ -39,7 +55,7 @@ class _Commit(metaclass=_MetaSingleton):
         self._db = db
 
     def __enter__(self):
-        pass
+        return self._db
 
     def __exit__(self, exc_type, exc_val, exc_tb):
-        self._db.session.commit()
\ No newline at end of file
+        self._db.session.commit()
